==> server-core-0.6.1-20161006.202020-1.jar: aclaimant/server/core/content_type.clj <==
(ns aclaimant.server.core.content-type
  (:require
    [aclaimant.server.core.request :as request]
    [camel-snake-kebab.core :as csk]
    [camel-snake-kebab.extras :as csk-extras]
    [cheshire.core :as json]))

(defn- ->json-keys [body]
  (if (string? body)
    body
    (-> body
        request/jsonify-keys
        (json/generate-string {:escape-non-ascii true}))))

(defn ->kebab-case-keyword [thing]
  (if-let [thing-ns (and (keyword? thing) (namespace thing))]
    (keyword thing-ns (csk/->kebab-case-string thing))
    (csk/->kebab-case-keyword thing)))

(defn ^:private ->edn [body]
  (pr-str
    (if (string? body)
      (csk-extras/transform-keys ->kebab-case-keyword (json/parse-string body))
      body)))

(defn transform-and-content-type [accept]
  (condp re-find (str accept)
    #"^application/edn" :edn
    #"^application/json" :json
    nil))

(def content-types
  {:json [->json-keys "application/json;charset=utf-8"]
   :edn [->edn "application/edn;charset=utf-8"] })

(defn wrap-content-type-response
  "Responds with a client-specified content-type"
  [handler & [default-accept]]
  (fn [request]
    (let [{:keys [headers] :as response} (handler request)]
      (if (contains? #{"text/html" "text/plain" "application/pdf"} (get headers "Content-Type"))
        response
        (let [default-accept (or default-accept :json)
              accept (get-in request [:headers "accept"])
              [transformer content-type] (content-types
                                           (or (transform-and-content-type accept) default-accept))]
          (-> response
              (update :body transformer)
              (update :headers assoc "Content-Type" content-type)))))))

==> server-core-0.6.2.jar: aclaimant/server/core/content_type.clj <==
(ns aclaimant.server.core.content-type
  (:require
    [aclaimant.server.core.request :as request]
    [camel-snake-kebab.core :as csk]
    [camel-snake-kebab.extras :as csk-extras]
    [cheshire.core :as json]
    [clojure.edn :as edn]))

(defn- ->json-keys [body]
  (if (string? body)
    body
    (-> body
        request/jsonify-keys
        (json/generate-string {:escape-non-ascii true}))))

(defn ->kebab-case-keyword [thing]
  (if-let [thing-ns (and (keyword? thing) (namespace thing))]
    (keyword thing-ns (csk/->kebab-case-string thing))
    (csk/->kebab-case-keyword thing)))

(defn ^:private ->edn [body]
  (let [edn-body (pr-str
                   (if (string? body)
                     (csk-extras/transform-keys ->kebab-case-keyword (json/parse-string body))
                     body))]
    (edn/read-string edn-body)
    edn-body))

(defn transform-and-content-type [accept]
  (condp re-find (str accept)
    #"^application/edn" :edn
    #"^application/json" :json
    nil))

(def content-types
  {:json [->json-keys "application/json;charset=utf-8"]
   :edn [->edn "application/edn;charset=utf-8"] })

(defn wrap-content-type-response
  "Responds with a client-specified content-type"
  [handler & [default-accept]]
  (fn [request]
    (let [{:keys [headers] :as response} (handler request)]
      (if (contains? #{"text/html" "text/plain" "application/pdf"} (get headers "Content-Type"))
        response
        (let [default-accept (or default-accept :json)
              accept (get-in request [:headers "accept"])
              content-type-kw (or (transform-and-content-type accept) default-accept)
              [transformer content-type] (content-types content-type-kw)
              response' (update response :headers assoc "Content-Type" content-type)]
          (try
            (update response' :body transformer)
            (catch Exception _
              (assoc response'
                     :body (transformer {:message (str "Failed converting body to " (name content-type-kw))})
                     :status 500))))))))
